@@ -544,7 +544,7 @@ class Bug(ndb.Model):
 
     return affects
 
-  def to_vulnerability(self, include_source=False, v0_7=True, v0_8=False):
+  def to_vulnerability(self, include_source=False, v0_7=False, v0_8=True):
     """Convert to Vulnerability proto."""
     package = None
     ecosystem_specific = None
@@ -569,7 +569,13 @@ class Bug(ndb.Model):
             ecosystem=affected_package.package.ecosystem,
             purl=affected_package.package.purl)
 
-        affects = self._get_pre_0_8_affects()
+        try:
+          affects = self._get_pre_0_8_affects()
+        except Exception:
+          # Unsupported conversion. Just skip for now since this code will be
+          # deleted very soon.
+          pass
+
         if affected_package.ecosystem_specific:
           ecosystem_specific = affected_package.ecosystem_specific
         if affected_package.database_specific:
@@ -659,7 +665,7 @@ class Bug(ndb.Model):
     if database_specific:
       result.database_specific.update(database_specific)
 
-    if source_link:
+    if source_link and v0_7:
       result.database_specific.update({'source': source_link})
 
     return result
@@ -744,6 +750,9 @@ def sorted_events(ecosystem, range_type, events):
   else:
     ecosystem_helper = ecosystems.get(ecosystem)
 
+  if ecosystem_helper is None:
+    raise ValueError('Unsupported ecosystem ' + ecosystem)
+
   # Remove any magic '0' values.
   sorted_copy = []
   zero_event = None
